@@ -1,6 +1,8 @@
 from pathlib import Path
 
-from airflow_e2e.composer.docker_compose_file.docker_compose_extras_yaml_file import DockerComposeExtrasYamlFile
+from airflow_e2e.composer.docker_compose_file.docker_compose_extras_yaml_file import (
+    DockerComposeExtrasYamlFile,
+)
 
 DOCKER_COMPOSE_EXTRAS_YAML_FILE_NAME = "docker-compose-extras.yml"
 
@@ -10,10 +12,10 @@ class ExtraServicesComposer:
         self.yaml_file = DockerComposeExtrasYamlFile()
 
     def with_mongodb(self) -> "ExtraServicesComposer":
-        self.yaml_file.with_mongo()
+        self.yaml_file = self.yaml_file.with_mongo()
         return self
 
     def setup(self, working_dir: Path):
         output_file_path = working_dir / DOCKER_COMPOSE_EXTRAS_YAML_FILE_NAME
-        with output_file_path.open(mode="w") as f:
-            f.write(self.yaml_file.content)
+        with output_file_path.open(mode="w") as output_file:
+            output_file.write(self.yaml_file.content)
